@@ -4,11 +4,17 @@
 #'
 #' @param dest Destination folder defaults to \code{getwd()}
 #'
-#' @details If function fails you can download the
+#' @details If the function fails you can download the
 #' extractor manually from \url{http://www.foolabs.com/xpdf/}
-#' (tested on Windows only)
+#' then set it manually as shown in examples \code{\link{get_emails}}
 #'
-#' @return Returns full path to pdftotext executable
+#' Tested on:
+#' \itemize{
+#'   \item{Windows}
+#'   \item{Linux}
+#' }
+#'
+#' @return Returns full path to \code{pdftotext} executable
 #'
 #' @seealso \code{\link{get_emails}}
 #'
@@ -21,13 +27,15 @@ get_xpdf <- function(dest = getwd()){
   lst <- OStoURI(os) # check os
   temp_zip <- tempfile(fileext = lst$ext) # create temp
   download.file(lst$uri, destfile = temp_zip) # download
-  unzip(zipfile = temp_zip, exdir = dest) # unzip
+  dec <- decompress_fun(temp_zip) # get decompress function
+  dec(temp_zip, exdir = dest) # unzip
   unlink("temp_zip", recursive=TRUE) # delete temp zip once unzipped
-  p <- list.files(paste0(dest, "/xpdfbin-win-3.04/bin64/"))
+  folder <- OS2folder(os)
+  p <- list.files(paste0(dest, folder))
   p <- p[grep("pdftotext", p)]
   message("xpdf successfully uzipped, use: \n",
-          dest, "xpdfbin-win-3.04/bin64/", p, "\n",
+          dest, folder, p, "\n",
           "as extractor in get_emails")
-  return(paste0(dest, "xpdfbin-win-3.04/bin64/", p))
+  return(paste0(dest, folder, p))
 }
 
